==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Layer/ts/Layer_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr_FR">
<context>
    <name>Layer</name>
    <message>
        <location filename="../Layer.js" line="+66"/>
        <source>Layer Tools</source>
        <translation>Outils de la couche</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Show layer tools</source>
        <translation>Afficher les outils de la couche</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>&amp;Layer</source>
        <translation>&amp;Calque</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Showing all layers</source>
        <translation>Afficher toutes les calques</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Hiding all layers</source>
        <translation>Cachez tous les calques</translation>
    </message>
    <message>
        <location line="+32"/>
        <source>Locking all layers</source>
        <translation>Verrouiller tous les calques</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Unlocking all layers</source>
        <translation>Déverrouiller tous les calques</translation>
    </message>
</context>
<context>
    <name>LayerDialog</name>
    <message>
        <location filename="../LayerDialog.ui" line="+17"/>
        <source>Layer Data</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Données du calque</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Layer name:</source>
        <translation>Nom du calque :</translation>
    </message>
    <message>
        <source>Pen</source>
        <translation type="vanished">Stylo</translation>
    </message>
    <message>
        <location line="+28"/>
        <source>Attributes</source>
        <translation>Attributs</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Color:</source>
        <translation>Couleur :</translation>
    </message>
    <message>
        <location line="+29"/>
        <source>Lineweight:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Epaisseur de la ligne :</translation>
    </message>
    <message>
        <location line="+26"/>
        <source>Linetype:</source>
        <translatorcomment>--ignored colon--
--file: LinetypeSettings_fr.ts--</translatorcomment>
        <translation>Type de ligne :</translation>
    </message>
    <message>
        <location filename="../LayerDialog.js" line="+176"/>
        <source>Leading or trailing spaces.</source>
        <translation>Espaces avant ou après.</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Layer name is empty.</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Nom du calque est vide.</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>Layer already exists.</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Calque existe déjà.</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Layer/ts/Layer_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr_FR">
<context>
    <name>Layer</name>
    <message>
        <location filename="../Layer.js" line="+97"/>
        <source>Layer Tools</source>
        <translation>Outils de la couche</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Show layer tools</source>
        <translation>Afficher les outils de la couche</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>&amp;Layer</source>
        <translation>&amp;Calque</translation>
    </message>
    <message>
        <location line="+43"/>
        <source>Showing all layers</source>
        <translation>Afficher toutes les calques</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Hiding all layers</source>
        <translation>Cachez tous les calques</translation>
    </message>
    <message>
        <location line="+46"/>
        <source>Thawing all layers</source>
        <translation>Décongeler toutes les calques</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Freezing all layers</source>
        <translation>Congélation tous les calques</translation>
    </message>
    <message>
        <location line="+31"/>
        <source>Locking all layers</source>
        <translation>Verrouiller tous les calques</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Unlocking all layers</source>
        <translation>Déverrouiller tous les calques</translation>
    </message>
</context>
<context>
    <name>LayerDialog</name>
    <message>
        <location filename="../LayerDialog.ui" line="+17"/>
        <source>Layer Data</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Données du calque</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Layer name:</source>
        <translation>Nom du calque :</translation>
    </message>
    <message>
        <source>Pen</source>
        <translation type="vanished">Stylo</translation>
    </message>
    <message>
        <location line="+28"/>
        <source>Attributes</source>
        <translation>Attributs</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Color:</source>
        <translation>Couleur :</translation>
    </message>
    <message>
        <location line="+29"/>
        <source>Lineweight:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Epaisseur de la ligne :</translation>
    </message>
    <message>
        <location line="+26"/>
        <source>Linetype:</source>
        <translatorcomment>--ignored colon--
--file: LinetypeSettings_fr.ts--</translatorcomment>
        <translation>Type de ligne :</translation>
    </message>
    <message>
        <location filename="../LayerDialog.js" line="+191"/>
        <source>Leading or trailing spaces.</source>
        <translation>Espaces avant ou après.</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Layer name is empty.</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Nom du calque est vide.</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Layer already exists.</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Calque existe déjà.</translation>
    </message>
</context>
</TS>
